# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 1.8.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from public_api_server_connector_v2.models.file_transcription_content_result import FileTranscriptionContentResult
from public_api_server_connector_v2.models.transcription_status import TranscriptionStatus
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class FileTranscriptionResult(BaseModel):
    """
    FileTranscriptionResult
    """ # noqa: E501
    id: StrictInt = Field(description="Mediastorage database ID of the file, the same ID used to retrieve the file metadata.")
    file_id: StrictStr = Field(description="Unique file hash identifier that can be used to retrieve the file later")
    file_type: StrictStr = Field(description="Type of the transcribed media file, either 'video' or 'audio'.")
    status: TranscriptionStatus = Field(description="Transcription status. The transcription content is only available when the status is 'finished'.")
    file_transcription: Optional[FileTranscriptionContentResult] = Field(default=None, description="Transcription content with full text and timestamped segments. Null unless the status is 'finished'.")
    updated_at: Optional[StrictInt] = Field(default=None, description="Date of the last manual transcription edit in epoch milliseconds. Null if never edited.")
    error_description: Optional[StrictStr] = Field(default=None, description="Error description if the transcription failed, null otherwise.")
    __properties: ClassVar[List[str]] = ["id", "file_id", "file_type", "status", "file_transcription", "updated_at", "error_description"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of FileTranscriptionResult from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of file_transcription
        if self.file_transcription:
            _dict['file_transcription'] = self.file_transcription.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of FileTranscriptionResult from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "file_id": obj.get("file_id"),
            "file_type": obj.get("file_type"),
            "status": obj.get("status"),
            "file_transcription": FileTranscriptionContentResult.from_dict(obj["file_transcription"]) if obj.get("file_transcription") is not None else None,
            "updated_at": obj.get("updated_at"),
            "error_description": obj.get("error_description")
        })
        return _obj


