# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 1.8.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.models.marketplace_buyer import MarketplaceBuyer

class TestMarketplaceBuyer(unittest.TestCase):
    """MarketplaceBuyer unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> MarketplaceBuyer:
        """Test MarketplaceBuyer
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `MarketplaceBuyer`
        """
        model = MarketplaceBuyer()
        if include_optional:
            return MarketplaceBuyer(
                email = '',
                first_name = '',
                last_name = '',
                phone_number = '',
                address = public_api_server_connector_v2.models.address.Address(
                    street_and_number = '', 
                    city = '', 
                    postal_code = '', 
                    country = '', )
            )
        else:
            return MarketplaceBuyer(
                email = '',
        )
        """

    def testMarketplaceBuyer(self):
        """Test MarketplaceBuyer"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
