# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 1.8.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.models.course_module_simple import CourseModuleSimple

class TestCourseModuleSimple(unittest.TestCase):
    """CourseModuleSimple unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CourseModuleSimple:
        """Test CourseModuleSimple
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CourseModuleSimple`
        """
        model = CourseModuleSimple()
        if include_optional:
            return CourseModuleSimple(
                mandatory = True,
                is_published = True,
                is_active = True,
                title = '',
                public_description = '',
                short_description = '',
                image_id = '',
                available_at = 56,
                id = 56,
                course_id = 56,
                order = 56
            )
        else:
            return CourseModuleSimple(
                title = '',
                id = 56,
                course_id = 56,
                order = 56,
        )
        """

    def testCourseModuleSimple(self):
        """Test CourseModuleSimple"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
