# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 1.8.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.models.file_transcription_result import FileTranscriptionResult

class TestFileTranscriptionResult(unittest.TestCase):
    """FileTranscriptionResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FileTranscriptionResult:
        """Test FileTranscriptionResult
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FileTranscriptionResult`
        """
        model = FileTranscriptionResult()
        if include_optional:
            return FileTranscriptionResult(
                id = 56,
                file_id = '',
                file_type = '',
                status = 'in_progress',
                file_transcription = public_api_server_connector_v2.models.file_transcription_content_result.FileTranscriptionContentResult(
                    transcription = '', 
                    segments = [
                        public_api_server_connector_v2.models.file_transcription_segment_result.FileTranscriptionSegmentResult(
                            order = 56, 
                            started_at = '', 
                            finished_at = '', 
                            transcription = '', )
                        ], ),
                updated_at = 56,
                error_description = ''
            )
        else:
            return FileTranscriptionResult(
                id = 56,
                file_id = '',
                file_type = '',
                status = 'in_progress',
        )
        """

    def testFileTranscriptionResult(self):
        """Test FileTranscriptionResult"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
